# Analytics Engine Agent

TBC

## Getting Started

TBC

### Prerequisites

TBC

### Installing

TBC

## Running the tests

TBC

## Deployment

TBC

## Built With

* [Python](https://www.python.org/) - Python

## Contributing

Please read [CONTRIBUTING.md](https://bitbucket.org/!api/2.0/snippets/fxquants/zAajL4/master/files/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting changes.

## Versioning

We use [SemVer](http://semver.org/) for versioning which is managed by bitbucket pipelines.
To increment the version update the package.json and package.lock.json before triggering a release in bitbucket pipelines.

## Authors

* **Jonathan Turnock** - *Initial work* - [fxq-jonathan_turnock](https://bitbucket.org/fxq-jonathan_turnock)

## License

This project is licensed under the [Creative Commons Attribution NonCommercial NoDerivs (CC-NC-ND)](https://creativecommons.org/licenses/by-nc-nd/3.0/) License - see the [LICENSE.md](https://bitbucket.org/!api/2.0/snippets/fxquants/zAajL4/master/files/LICENSE.md) file for details

## Acknowledgments

TBC